@@ -23,11 +23,11 @@
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
+#include <math.h>
 
 #include "gnome-settings-profile.h"
 #include "gsd-color-calibrate.h"
 #include "gsd-color-manager.h"
-#include "gsd-color-profiles.h"
 #include "gsd-color-state.h"
 #include "gsd-night-light.h"
 
@@ -64,7 +64,6 @@ struct _GsdColorManager
         GCancellable      *bus_cancellable;
 
         GsdColorCalibrate *calibrate;
-        GsdColorProfiles  *profiles;
         GsdColorState     *state;
         GsdNightLight   *nlight;
 
@@ -96,21 +95,14 @@ gboolean
 gsd_color_manager_start (GsdColorManager *manager,
                          GError          **error)
 {
-        gboolean ret;
-
         g_debug ("Starting color manager");
         gnome_settings_profile_start (NULL);
 
         /* start the device probing */
         gsd_color_state_start (manager->state);
 
-        /* start the profiles collection */
-        ret = gsd_color_profiles_start (manager->profiles, error);
-        if (!ret)
-                goto out;
-out:
         gnome_settings_profile_end (NULL);
-        return ret;
+        return TRUE;
 }
 
 void
@@ -118,7 +110,6 @@ gsd_color_manager_stop (GsdColorManager *manager)
 {
         g_debug ("Stopping color manager");
         gsd_color_state_stop (manager->state);
-        gsd_color_profiles_stop (manager->profiles);
 }
 
 static void
@@ -211,7 +202,7 @@ on_temperature_notify (GsdNightLight *nlight,
         gdouble temperature = gsd_night_light_get_temperature (manager->nlight);
         gsd_color_state_set_temperature (manager->state, temperature);
         emit_property_changed (manager, "Temperature",
-                               g_variant_new_double (temperature));
+                               g_variant_new_uint32 (roundf (temperature)));
 }
 
 static void
@@ -219,7 +210,6 @@ gsd_color_manager_init (GsdColorManager *manager)
 {
         /* setup calibration features */
         manager->calibrate = gsd_color_calibrate_new ();
-        manager->profiles = gsd_color_profiles_new ();
         manager->state = gsd_color_state_new ();
 
         /* night light features */
@@ -265,7 +255,6 @@ gsd_color_manager_finalize (GObject *object)
                 g_source_remove (manager->nlight_forced_timeout_id);
 
         g_clear_object (&manager->calibrate);
-        g_clear_object (&manager->profiles);
         g_clear_object (&manager->state);
         g_clear_object (&manager->nlight);
 
