@@ -24,6 +24,10 @@
 #error Include PLUGIN_CFLAGS in the daemon s CFLAGS
 #endif /* !PLUGIN_NAME */
 
+#ifndef PLUGIN_DBUS_NAME
+#error Include PLUGIN_DBUS_NAME in the daemon s CFLAGS
+#endif /* !PLUGIN_DBUS_NAME */
+
 #define GNOME_SESSION_DBUS_NAME                     "org.gnome.SessionManager"
 #define GNOME_SESSION_CLIENT_PRIVATE_DBUS_INTERFACE "org.gnome.SessionManager.ClientPrivate"
 
@@ -39,36 +43,6 @@ static GOptionEntry entries[] = {
         {NULL}
 };
 
-static const char *gdm_helpers[] = {
-	"a11y-keyboard",
-	"a11y-settings",
-	"clipboard",
-	"color",
-	"keyboard",
-	"media-keys",
-	"power",
-	"smartcard",
-	"sound",
-	"xsettings"
-};
-
-static gboolean
-should_run (void)
-{
-	const char *session_mode;
-	guint i;
-
-	session_mode = g_getenv ("GNOME_SHELL_SESSION_MODE");
-	if (g_strcmp0 (session_mode, "gdm") != 0)
-		return TRUE;
-
-	for (i = 0; i < G_N_ELEMENTS (gdm_helpers); i++) {
-		if (g_str_equal (PLUGIN_NAME, gdm_helpers[i]))
-			return TRUE;
-	}
-	return FALSE;
-}
-
 static void
 respond_to_end_session (GDBusProxy *proxy)
 {
@@ -192,12 +166,37 @@ install_signal_handler (GMainLoop *loop)
   g_source_attach (source, NULL);
 }
 
+static void
+bus_acquired_cb (GDBusConnection *connection,
+                 const gchar *name,
+                 gpointer user_data G_GNUC_UNUSED)
+{
+        g_debug ("%s: acquired bus %p for name %s", G_STRFUNC, connection, name);
+}
+
+static void
+name_acquired_cb (GDBusConnection *connection,
+                  const gchar *name,
+                  gpointer user_data G_GNUC_UNUSED)
+{
+        g_debug ("%s: acquired name %s on bus %p", G_STRFUNC, name, connection);
+}
+
+static void
+name_lost_cb (GDBusConnection *connection,
+              const gchar *name,
+              gpointer user_data G_GNUC_UNUSED)
+{
+        g_debug ("%s: lost name %s on bus %p", G_STRFUNC, name, connection);
+}
+
 int
 main (int argc, char **argv)
 {
         GError *error = NULL;
         GOptionContext *context;
         GMainLoop *loop;
+        guint name_own_id;
 
         bindtextdomain (GETTEXT_PACKAGE, GNOME_SETTINGS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -239,20 +238,27 @@ main (int argc, char **argv)
         manager = NEW ();
 	register_with_gnome_session (loop);
 
-	if (should_run ()) {
-		error = NULL;
-		if (!START (manager, &error)) {
-			fprintf (stderr, "Failed to start: %s\n", error->message);
-			g_error_free (error);
-			exit (1);
-		}
-	}
+        if (!START (manager, &error)) {
+                fprintf (stderr, "Failed to start: %s\n", error->message);
+                g_error_free (error);
+                exit (1);
+        }
+
+	name_own_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+				      PLUGIN_DBUS_NAME,
+				      G_BUS_NAME_OWNER_FLAGS_DO_NOT_QUEUE,
+				      bus_acquired_cb,
+				      name_acquired_cb,
+				      name_lost_cb,
+				      NULL, /* user_data */
+				      NULL /* user_data_free_func */);
 
         g_main_loop_run (loop);
 
-	if (should_run ())
-		STOP (manager);
+        STOP (manager);
+
         g_object_unref (manager);
+        g_bus_unown_name (name_own_id);
 
         return 0;
 }
