@@ -57,10 +57,6 @@
 
 #define GNOME_DESKTOP_INTERFACE_DIR "org.gnome.desktop.interface"
 
-#define KEY_GTK_IM_MODULE    "gtk-im-module"
-#define GTK_IM_MODULE_SIMPLE "gtk-im-context-simple"
-#define GTK_IM_MODULE_IBUS   "ibus"
-
 #define GNOME_DESKTOP_INPUT_SOURCES_DIR "org.gnome.desktop.input-sources"
 
 #define KEY_INPUT_SOURCES        "sources"
@@ -71,8 +67,7 @@
 
 #define DEFAULT_LAYOUT "us"
 
-#define GNOME_A11Y_APPLICATIONS_INTERFACE_DIR "org.gnome.desktop.a11y.applications"
-#define KEY_OSK_ENABLED "screen-keyboard-enabled"
+#define SETTINGS_PORTED_FILE ".gsd-keyboard.settings-ported"
 
 struct _GsdKeyboardManager
 {
@@ -81,21 +76,14 @@ struct _GsdKeyboardManager
         guint      start_idle_id;
         GSettings *settings;
         GSettings *input_sources_settings;
-        GSettings *a11y_settings;
         GDBusProxy *localed;
         GCancellable *cancellable;
-
-        GdkDeviceManager *device_manager;
-        guint device_added_id;
-        guint device_removed_id;
 };
 
 static void     gsd_keyboard_manager_class_init  (GsdKeyboardManagerClass *klass);
 static void     gsd_keyboard_manager_init        (GsdKeyboardManager      *keyboard_manager);
 static void     gsd_keyboard_manager_finalize    (GObject                 *object);
 
-static void     update_gtk_im_module (GsdKeyboardManager *manager);
-
 G_DEFINE_TYPE (GsdKeyboardManager, gsd_keyboard_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
@@ -218,121 +206,6 @@ settings_changed (GSettings          *settings,
 
 }
 
-static void
-device_added_cb (GdkDeviceManager   *device_manager,
-                 GdkDevice          *device,
-                 GsdKeyboardManager *manager)
-{
-        GdkInputSource source;
-
-        source = gdk_device_get_source (device);
-        if (source == GDK_SOURCE_TOUCHSCREEN) {
-                update_gtk_im_module (manager);
-        }
-}
-
-static void
-device_removed_cb (GdkDeviceManager   *device_manager,
-                   GdkDevice          *device,
-                   GsdKeyboardManager *manager)
-{
-        GdkInputSource source;
-
-        source = gdk_device_get_source (device);
-        if (source == GDK_SOURCE_TOUCHSCREEN)
-                update_gtk_im_module (manager);
-}
-
-static void
-set_devicepresence_handler (GsdKeyboardManager *manager)
-{
-        GdkDeviceManager *device_manager;
-
-        if (gnome_settings_is_wayland ())
-                return;
-
-        device_manager = gdk_display_get_device_manager (gdk_display_get_default ());
-
-        manager->device_added_id = g_signal_connect (G_OBJECT (device_manager), "device-added",
-                                                           G_CALLBACK (device_added_cb), manager);
-        manager->device_removed_id = g_signal_connect (G_OBJECT (device_manager), "device-removed",
-                                                             G_CALLBACK (device_removed_cb), manager);
-        manager->device_manager = device_manager;
-}
-
-static gboolean
-need_ibus (GVariant *sources)
-{
-        GVariantIter iter;
-        const gchar *type;
-
-        g_variant_iter_init (&iter, sources);
-        while (g_variant_iter_next (&iter, "(&s&s)", &type, NULL))
-                if (g_str_equal (type, INPUT_SOURCE_TYPE_IBUS))
-                        return TRUE;
-
-        return FALSE;
-}
-
-static gboolean
-need_osk (GsdKeyboardManager *manager)
-{
-        gboolean has_touchscreen = FALSE;
-        GList *devices;
-        GdkSeat *seat;
-
-        if (g_settings_get_boolean (manager->a11y_settings,
-                                    KEY_OSK_ENABLED))
-                return TRUE;
-
-        seat = gdk_display_get_default_seat (gdk_display_get_default ());
-        devices = gdk_seat_get_slaves (seat, GDK_SEAT_CAPABILITY_TOUCH);
-
-        has_touchscreen = devices != NULL;
-
-        g_list_free (devices);
-
-        return has_touchscreen;
-}
-
-static void
-set_gtk_im_module (GsdKeyboardManager *manager,
-                   GSettings          *settings,
-                   GVariant           *sources)
-{
-        const gchar *new_module;
-        gchar *current_module;
-
-        if (need_ibus (sources) || need_osk (manager))
-                new_module = GTK_IM_MODULE_IBUS;
-        else
-                new_module = GTK_IM_MODULE_SIMPLE;
-
-        current_module = g_settings_get_string (settings, KEY_GTK_IM_MODULE);
-        if (!g_str_equal (current_module, new_module))
-                g_settings_set_string (settings, KEY_GTK_IM_MODULE, new_module);
-        g_free (current_module);
-}
-
-static void
-update_gtk_im_module (GsdKeyboardManager *manager)
-{
-        GSettings *interface_settings;
-        GVariant *sources;
-
-        /* Gtk+ uses the IM module advertised in XSETTINGS so, if we
-         * have IBus input sources, we want it to load that
-         * module. Otherwise we can use the default "simple" module
-         * which is builtin gtk+
-         */
-        interface_settings = g_settings_new (GNOME_DESKTOP_INTERFACE_DIR);
-        sources = g_settings_get_value (manager->input_sources_settings,
-                                        KEY_INPUT_SOURCES);
-        set_gtk_im_module (manager, interface_settings, sources);
-        g_object_unref (interface_settings);
-        g_variant_unref (sources);
-}
-
 static void
 get_sources_from_xkb_config (GsdKeyboardManager *manager)
 {
@@ -580,18 +453,7 @@ start_keyboard_idle_cb (GsdKeyboardManager *manager)
 
         manager->settings = g_settings_new (GSD_KEYBOARD_DIR);
 
-	set_devicepresence_handler (manager);
-
         manager->input_sources_settings = g_settings_new (GNOME_DESKTOP_INPUT_SOURCES_DIR);
-        g_signal_connect_swapped (manager->input_sources_settings,
-                                  "changed::" KEY_INPUT_SOURCES,
-                                  G_CALLBACK (update_gtk_im_module), manager);
-
-        manager->a11y_settings = g_settings_new (GNOME_A11Y_APPLICATIONS_INTERFACE_DIR);
-        g_signal_connect_swapped (manager->a11y_settings,
-                                  "changed::" KEY_OSK_ENABLED,
-                                  G_CALLBACK (update_gtk_im_module), manager);
-        update_gtk_im_module (manager);
 
         manager->cancellable = g_cancellable_new ();
 
@@ -645,14 +507,7 @@ gsd_keyboard_manager_stop (GsdKeyboardManager *manager)
 
         g_clear_object (&manager->settings);
         g_clear_object (&manager->input_sources_settings);
-        g_clear_object (&manager->a11y_settings);
         g_clear_object (&manager->localed);
-
-        if (manager->device_manager != NULL) {
-                g_signal_handler_disconnect (manager->device_manager, manager->device_added_id);
-                g_signal_handler_disconnect (manager->device_manager, manager->device_removed_id);
-                manager->device_manager = NULL;
-        }
 }
 
 static void
@@ -688,6 +543,14 @@ gsd_keyboard_manager_finalize (GObject *object)
         G_OBJECT_CLASS (gsd_keyboard_manager_parent_class)->finalize (object);
 }
 
+static GVariant *
+reset_gtk_im_module (GVariant *variant,
+                     GVariant *old_default,
+                     GVariant *new_default)
+{
+        return NULL;
+}
+
 static void
 migrate_keyboard_settings (void)
 {
@@ -697,12 +560,37 @@ migrate_keyboard_settings (void)
                 { "delay",                  "delay",                  NULL },
                 { "remember-numlock-state", "remember-numlock-state", NULL },
         };
+        g_autofree char *filename = NULL;
 
         gsd_settings_migrate_check ("org.gnome.settings-daemon.peripherals.keyboard.deprecated",
                                     "/org/gnome/settings-daemon/peripherals/keyboard/",
                                     "org.gnome.desktop.peripherals.keyboard",
                                     "/org/gnome/desktop/peripherals/keyboard/",
                                     entries, G_N_ELEMENTS (entries));
+
+        /* In prior versions to GNOME 42, the gtk-im-module setting was
+         * owned by gsd-keyboard. Reset it once before giving it back
+         * to the user.
+         */
+        filename = g_build_filename (g_get_user_config_dir (),
+                                     SETTINGS_PORTED_FILE,
+                                     NULL);
+
+        if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+                GsdSettingsMigrateEntry im_entry[] = {
+                        { "gtk-im-module", "gtk-im-module", reset_gtk_im_module },
+                };
+                g_autoptr(GError) error = NULL;
+
+                gsd_settings_migrate_check ("org.gnome.desktop.interface",
+                                            "/org/gnome/desktop/interface/",
+                                            "org.gnome.desktop.interface",
+                                            "/org/gnome/desktop/interface/",
+                                            im_entry, G_N_ELEMENTS (im_entry));
+
+                if (!g_file_set_contents (filename, "", -1, &error))
+                        g_warning ("Error migrating gtk-im-module: %s", error->message);
+        }
 }
 
 GsdKeyboardManager *
